Poort: The quick gateway.
==================================================================

.. begin

Poort is a bundle of best-practices to quickly build web gateways.

* Free software: MIT license
* Documentation: http://pythonhosted.org/poort

A quick example::

    # todo


Features
--------

* TODO

Authors
-------

``Poort`` is written and maintained by
`Nils Corver <nils@corverdevelopment.nl>`_.

A full list of contributors can be found in
`GitHub's overview <https://github.com/corverdevelopment/poort/graphs/contributors>`_.
